.. SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _credible.references:

============
 References
============

.. [GOUTTE-2005] *C. Goutte and E. Gaussier*, **A probabilistic interpretation
   of precision, recall and F-score, with implication for evaluation**.
   European conference on Advances in Information Retrieval Research, 2005.
   https://doi.org/10.1007/978-3-540-31865-1_25

.. [CLOPPER-1934] *C. J. Clopper and E. S. Pearson*, **The use of confidence or
   fiducial limits illustrated in the case of the Binomial**, Biometrika, vol.
   26, no. 4, pp. 404–413, 1934, https://doi.org/10.1093/biomet/26.4.404

.. [AGRESTI-1998] *A. Agresti and B. A. Coull*, **Approximate Is Better than
   "Exact" for Interval Estimation of Binomial Proportions**, The American
   Statistician, vol. 52, no. 2, p. 119, May 1998,
   https://doi.org/10.2307/2685469

.. [WILSON-1927] *E. B. Wilson*, **Probable Inference, the Law of Succession,
   and Statistical Inference**, Journal of the American Statistical
   Association, vol. 22, no. 158, pp. 209–212, Jun. 1927,
   https://doi.org/10.1080/01621459.1927.10502953
